@@ -34,6 +34,7 @@ class Graphics(
         """
         from apyscript.display import Sprite
         from apyscript.expression import expression_variables_util
+        from apyscript.expression import var_names
         from apyscript.type import Array
         from apyscript.type import Number
         from apyscript.type import String
@@ -43,7 +44,7 @@ class Graphics(
         self.parent_sprite: Sprite = parent
         if variable_name is None:
             variable_name = expression_variables_util.get_next_variable_name(
-                type_name='graphics')
+                type_name=var_names.GRAPHICS)
         self.variable_name = variable_name
         self._fill_color = String('')
         self._fill_alpha = Number(1.0)
