@@ -21,10 +21,11 @@ class Number(NumberValueInterface):
         """
         from apyscript.converter import cast
         from apyscript.expression import expression_variables_util
-        type_name: str = 'number'
+        from apyscript.expression import var_names
+        TYPE_NAME: str = var_names.NUMBER
         self.variable_name = expression_variables_util.get_next_variable_name(
-            type_name=type_name)
-        super(Number, self).__init__(value=value, type_name=type_name)
+            type_name=TYPE_NAME)
+        super(Number, self).__init__(value=value, type_name=TYPE_NAME)
         self._value = cast.to_float_from_int(int_or_float=self.value)
         self.append_constructor_expression()
 
